#
# spec file for package syncthing
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           syncthing
Version:        0.14.31
Release:        0
Summary:        FOSS Continuous File Synchronisation
License:        MPL-2.0
Group:          Productivity/Networking/File-Sharing
Url:            https://syncthing.net/
Source:         https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-source-v%{version}.tar.gz
Source1:        https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-source-v%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source3:        %{name}.firewall
BuildRequires:  go >= 1.5
BuildRequires:  systemd
BuildRequires:  systemd-rpm-macros
%if 0%{?suse_version} <= 1320
BuildRequires:  golang-org-x-net-context
%endif

%description
Syncthing replaces proprietary sync and cloud services with
something open, trustworthy and decentralised. Your data is your
data alone and you deserve to choose where it is stored, if it is
shared with some third party and how it's transmitted over the
Internet.

%prep
%setup -q -n %{name}

cp -f %{SOURCE3} %{name}.firewall
%if !(0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200)
# Remove entries which only exist since systemd 215.
sed -i '/^RestartForceExitStatus=/d;s/^\(SuccessExitStatus=\).*$/\12/' \
  etc/linux-systemd/system/syncthing@.service
%endif
%if 0%{?suse_version} <= 1320
find -type f -name '*.go' -exec sed -i 's|"context"|"golang.org/x/net/context"|' {} \;
%endif

%build
mkdir -p build/src/ build/vendor/
export GOPATH="$PWD/build:$PWD/build/vendor"

mkdir -p build/src/github.com/%{name}/%{name}
ls | sed '/^build$/d' | xargs cp -at build/src/github.com/%{name}/%{name}
cp -a vendor build/vendor/src

pushd build/src/github.com/%{name}/%{name}/
go run build.go install all \
  -version v%{version} -no-upgrade
popd

%install
install -Dpm 0755 build/src/github.com/%{name}/%{name}/bin/%{name} \
  %{buildroot}%{_bindir}/%{name}
install -Dpm 0644 etc/linux-systemd/system/%{name}@.service        \
  %{buildroot}%{_unitdir}/%{name}@.service
install -Dpm 0644 etc/linux-systemd/system/%{name}-resume.service  \
  %{buildroot}%{_unitdir}/%{name}-resume.service
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
install -Dpm 0644 etc/linux-systemd/user/%{name}.service           \
  %{buildroot}%{_userunitdir}/%{name}.service
%endif
install -Dpm 0644 %{name}.firewall                                 \
  %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}

%pre
%service_add_pre %{name}-resume.service

%post
%service_add_post %{name}-resume.service
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%systemd_user_post %{name}.service
%endif

%preun
%service_del_preun %{name}@.service %{name}-resume.service
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%systemd_user_preun %{name}.service
%endif

%postun
%service_del_postun %{name}-resume.service
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%systemd_user_postun %{name}.service
%endif

%files
%defattr(-,root,root)
%doc AUTHORS CONDUCT.md CONTRIBUTING.md LICENSE README.md
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}
%{_bindir}/%{name}
%{_unitdir}/%{name}@.service
%{_unitdir}/%{name}-resume.service
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%{_userunitdir}/%{name}.service
%endif

%changelog
